@@ -4,14 +4,15 @@
 #'
 #' A colour input allows users to select a colour by clicking on the desired
 #' colour, or by entering a valid HEX colour in the input box. The input can
-#' be initialized with either a colour name or a HEX value, but the value
-#' returned from the input will be an uppercase HEX value in both cases.
+#' be initialized with either a colour name or a HEX value. The return value is
+#' a HEX value by default, but you can use the \code{returnName = TRUE} parameter
+#' to get an R colour name instead (only when an R colour exists for the
+#' selected colour).
 #'
 #' Since most functions in R that accept colours can also accept the value
 #' "transparent", \code{colourInput} has an option to allow selecting the
 #' "transparent" colour. When the user checks the checkbox for this special
-#' colour, the returned value form the input is "transpanrent", otherwise the
-#' return value is always a HEX value.
+#' colour, the returned value form the input is "transparent".
 #'
 #' @param inputId The \code{input} slot that will be used to access the value.
 #' @param label Display label for the control, or `\code{NULL} for no label.
@@ -32,6 +33,8 @@
 #' "Transparent", but you can change it to "None" or any other string. This has
 #' no effect on the return value from the input; when the checkbox is checked,
 #' the input will always return the string "transparent".
+#' @param returnName If \code{TRUE}, then return the name of an R colour instead
+#' of a HEX value when possible.
 #' @seealso \code{\link[shinyjs]{updateColourInput}}
 #' \code{\link[shinyjs]{colourPicker}}
 #' @examples
@@ -48,6 +51,7 @@
 #'       selectInput("palette", "Colour palette",
 #'         c("square", "limited")),
 #'       checkboxInput("allowTransparent", "Allow transparent", FALSE),
+#'       checkboxInput("returnName", "Return R colour name", FALSE),
 #'       actionButton("btn", "Update")
 #'     ),
 #'     server = function(input, output, session) {
@@ -55,7 +59,8 @@
 #'         updateColourInput(session, "col",
 #'           value = input$text, showColour = input$showColour,
 #'           allowTransparent = input$allowTransparent,
-#'           palette = input$palette)
+#'           palette = input$palette,
+#'           returnName = input$returnName)
 #'       })
 #'       output$value <- renderText(input$col)
 #'     }
@@ -70,7 +75,8 @@ colourInput <- function(inputId, label, value = "white",
                         showColour = c("both", "text", "background"),
                         palette = c("square", "limited"),
                         allowedCols,
-                        allowTransparent = FALSE, transparentText) {
+                        allowTransparent = FALSE, transparentText,
+                        returnName = FALSE) {
   # sanitize the arguments
   value <- formatHEX(value)
   showColour <- match.arg(showColour)
@@ -118,6 +124,11 @@ colourInput <- function(inputId, label, value = "white",
       inputTag,
       `data-allowed-cols` = allowedCols)
   }
+  if (returnName) {
+    inputTag <- shiny::tagAppendAttributes(
+      inputTag,
+      `data-return-name` = "true")
+  }
 
   inputTag <-
     shiny::div(
@@ -151,6 +162,8 @@ colourInput <- function(inputId, label, value = "white",
 #' user to select the \code{transparent} colour.
 #' @param transparentText The text to show beside the transparency checkbox
 #' when \code{allowTransparent} is \code{TRUE}
+#' @param returnName If \code{TRUE}, then return the name of an R colour instead
+#' of a HEX value when possible.
 #' @seealso \code{\link[shinyjs]{colourInput}}
 #' @examples
 #' if (interactive()) {
@@ -164,13 +177,15 @@ colourInput <- function(inputId, label, value = "white",
 #'       selectInput("showColour", "Show colour",
 #'         c("both", "text", "background")),
 #'       checkboxInput("allowTransparent", "Allow transparent", FALSE),
+#'       checkboxInput("returnName", "Return R colour name", FALSE),
 #'       actionButton("btn", "Update")
 #'     ),
 #'     server = function(input, output, session) {
 #'       observeEvent(input$btn, {
 #'         updateColourInput(session, "col",
 #'           value = input$text, showColour = input$showColour,
-#'           allowTransparent = input$allowTransparent)
+#'           allowTransparent = input$allowTransparent,
+#'           returnName = input$returnName)
 #'       })
 #'       output$value <- renderText(input$col)
 #'     }
@@ -183,12 +198,14 @@ colourInput <- function(inputId, label, value = "white",
 #' @export
 updateColourInput <- function(session, inputId, label = NULL, value = NULL,
                               showColour = NULL, palette = NULL, allowedCols = NULL,
-                              allowTransparent = NULL, transparentText = NULL) {
+                              allowTransparent = NULL, transparentText = NULL,
+                              returnName = NULL) {
   message <- dropNulls(list(
     label = label, value = formatHEX(value),
     showColour = showColour, palette = palette,
     allowedCols = formatHEX(allowedCols),
-    allowTransparent = allowTransparent, transparentText = transparentText
+    allowTransparent = allowTransparent, transparentText = transparentText,
+    returnName = returnName
   ))
   session$sendInputMessage(inputId, message)
 }
