@@ -8,14 +8,14 @@ examples <- c(
   'info(R.Version())',
   'onclick("btn", info(date()))',
   'toggle(selector = "a")',
-  'toggle("btn", TRUE, "fade", 2)',
+  'toggle("btn", TRUE, "slide", 2)',
   'toggle(id = "btn", condition = (sample(2, 1) == 1))',
   'toggle(id = "btn", anim = TRUE, time = 1, animType = "slide")',
   'toggleState("btn")',
   'disable("btn")',
   'enable("btn")',
-  'text("btn", "What a nice button")',
-  'text("btn", paste("The time is", date()))',
+  'html("btn", "What a nice button")',
+  'html("btn", paste("The time is", date()))',
   'addClass("btn", "green")',
   'removeClass("btn", "green")',
   'toggleClass("btn", "green")'
@@ -39,7 +39,7 @@ helpText <- list(
   "toggleState" = "will alternate between enabling and disabling the button below",
   "disable"     = "will disable the button below from being clicked",
   "enable"      = "will allow the button below to be clicked",
-  "text"        = "will change the HTML content of an element",
+  "html"        = "will change the HTML contents of an element",
   "addClass"    = "will add a CSS class to an element",
   "removeClass" = "will remove a CSS class from an element",
   "toggleClass" = "will alternate between adding and removing a class from an element"
