@@ -3,7 +3,7 @@ examples <- c(
   'toggle("test")',
   'delay(500, toggle("test"))',
   'toggle(selector = "a")',
-  'toggle("test", TRUE, "fade", 2)',
+  'toggle("test", TRUE, "slide", 2)',
   'toggle(id = "test", anim = TRUE, time = 2, animType = "slide")',
   'hide("test")',
   'show("test")',
@@ -14,8 +14,8 @@ examples <- c(
   'disable("btn")',
   'enable("btn")',
   'toggle(id = "btn", condition = (sample(2, 1) == 1))',
-  'text("btn", "What a nice button")',
-  'text("test", paste("The time is", date()))',
+  'html("btn", "What a nice button")',
+  'html("test", paste("The time is", date()))',
   'addClass("test", "green")',
   'removeClass("test", "green")',
   'toggleClass("test", "green")'
